@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.484";
+our $VERSION = "0.485";
 
 1;
 
@@ -242,18 +242,24 @@ Returns a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object giving the status info for
 
 Changes the working directory to $path. The same as the Perl L<chdir|https://perldoc.perl.org/functions/chdir> function.
 
+If succeed, returns 1.
+
 =head2 chmod
 
   static method chmod : int ($mode :int, $path : string);
 
 Changes the permissions of a file. The same as the Perl L<chmod|https://perldoc.perl.org/functions/chmod> function.
 
+If succeed, returns 1.
+
 =head2 mkdir
 
   static method mkdir : int ($path : string, $mode : int);
 
 Creates the directory specified by $path and $mode. The same as the Perl L<mkdir|https://perldoc.perl.org/functions/mkdir> function.
 
+If succeed, returns 1.
+
 =head2 umask
 
   static method umask : int ($mode : int);
@@ -266,6 +272,8 @@ Sets the umask for the process to $mode and returns the previous value. The same
 
 Deletes the directory specified by $path. The same as the Perl L<rmdir|https://perldoc.perl.org/functions/rmdir> function.
 
+If succeed, returns 1.
+
 =head2 opendir
 
   static method opendir : int ($dh_ref : Sys::IO::DirStream[], $dir : string);
@@ -274,7 +282,7 @@ Calls the L<opendir|SPVM::Sys::IO/"opendir"> method in the L<Sys::Socket|SPVM::S
 
 The return value is set to $dh_ref->[0].
 
-If succeed, returns 1. Otherwise returns 0.
+If succeed, returns 1.
 
 =head2 closedir
 
@@ -282,7 +290,7 @@ If succeed, returns 1. Otherwise returns 0.
 
 Calls the L<opendir|SPVM::Sys::IO/"opendir"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
 
-If succeed, returns 1. Otherwise returns 0.
+If succeed, returns 1.
 
 =head2 unlink
 
@@ -290,12 +298,16 @@ If succeed, returns 1. Otherwise returns 0.
 
 Deletes a file. The same as the Perl L<unlink|https://perldoc.perl.org/functions/unlink> function.
 
+If succeed, returns 1.
+
 =head2 rename
 
   static method rename : int ($oldpath : string, $newpath : string);
 
 Changes the name of a file. The same as the Perl L<rename|https://perldoc.perl.org/functions/rename> function.
 
+If succeed, returns 1.
+
 =head2 readlink
 
   static method readlink : int ($file : string);
@@ -308,6 +320,8 @@ Returns the value of a symbolic link. The same as the Perl L<readlink|https://pe
 
 Creates a $newpath symbolically linked to the $oldpath. The same as the Perl L<symlink|https://perldoc.perl.org/functions/symlink> function.
 
+If succeed, returns 1.
+
 =head2 sleep
 
   static method sleep : int ($seconds : int);
@@ -324,9 +338,9 @@ Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys
 
 =head2 select
 
-  static method select : int ($nfds : int, $readfds : Sys::Select::Fd_set, $writefds : Sys::Select::Fd_set, $exceptfds : Sys::Select::Fd_set, $timeout : Sys::Time::Timeval);
+  static method select : int ($readfds : Sys::Select::Fd_set, $writefds : Sys::Select::Fd_set, $exceptfds : Sys::Select::Fd_set, $timeout : Sys::Time::Timeval);
 
-Calls the L<select|SPVM::Sys::Select/"select"> method in the L<Sys::Select|SPVM::Sys::Select> class.
+Calls the L<select|SPVM::Sys::Select/"select"> method in the L<Sys::Select|SPVM::Sys::Select> class with the $ndfs set to 1024.
 
 =head2 bind
 
